@@ -15,6 +15,11 @@ def runner():
     return Runner(greeting="Hello")
 
 
+@pytest.fixture()
+def contextless_runner():
+    return Runner()
+
+
 @pytest.fixture
 def simple_sql_path():
     return "tests/files/simple.sql"
@@ -41,6 +46,18 @@ def test_render_text_only(runner):
     assert got == want
 
 
+def test_render_extra_context(runner):
+    got = runner.render("{{new_greeting}}, {{env_var('name')}}!", new_greeting="Hey")
+    want = "Hey, Bob!"
+    assert got == want
+
+
+def test_contextless_runner(contextless_runner):
+    got = contextless_runner.render("{{no_greeting}}, Bill!")
+    want = "{{ no_greeting }}, Bill!"
+    assert got == want
+
+
 def test_replace_only_changes(runner):
     original = runner.render("{{env_switch(foo='address')}} and {{greeting}}")
     assert original == "value_unspecified and Hello"
